# tap-dynamodb

[![CircleCI](https://circleci.com/gh/singer-io/tap-dynamodb.svg?style=svg)](https://circleci.com/gh/singer-io/tap-dynamodb)

This is a [Singer](https://singer.io) tap that produces JSON-formatted data
following the [Singer
spec](https://github.com/singer-io/getting-started/blob/master/SPEC.md).

Copyright &copy; 2019 Stitch
